@@ -1,7 +1,7 @@
 //  -*-C++-*-           emacs magic for .h files
 /*
 
- $Id: ar.h 345087 2004-09-08 20:19:07Z henrique $
+ $Id: ar.h 490596 2005-12-22 13:05:45Z scripty $
 
  ark -- archiver for the KDE project
 
@@ -23,7 +23,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -52,8 +52,7 @@ public:
   virtual void addDir(const QString &) {} // never gets called
 
   virtual void remove(QStringList *);
-  virtual void unarchFile(QStringList *, const QString & _destDir="",
-			  bool viewFriendly=false);
+  virtual void unarchFileInternal();
 
 private:
   void setHeaders();
