@@ -25,9 +25,9 @@ Arguments::~Arguments()
 const QString Arguments::toString() const
 {
 	QString ret = "";
-	for(Arguments::const_iterator i = begin(); i != end(); i++)
+	for(Arguments::const_iterator i = begin(); i != end(); ++i)
 	{	QString s = (*i).toString();
-		if(s == QString::null) s = "...";
+		if(s.isNull()) s = "...";
 		if(i != begin()) ret += ", ";
 		ret += s;
 	}
