@@ -24,7 +24,7 @@
 #include <qstring.h>
 #include <qlabel.h>
 #include <qapplication.h>
-#include <kio/netaccess.h> 
+#include <kio/netaccess.h>
 #include <qcheckbox.h>
 
 #include <kmessagebox.h>
@@ -61,7 +61,7 @@ FILE *fp;
 	bool readLine=true;
 
         QString gpgcmd="gpg --version";
-        
+
         fp = popen(QFile::encodeName(gpgcmd), "r");
         while ( fgets( buffer, sizeof(buffer), fp)) {
                 readResult=buffer;
@@ -94,20 +94,20 @@ void KgpgInterface::KgpgEncryptFile(QStringList encryptKeys,KURL srcUrl,KURL des
         sourceFile=srcUrl;
         message=QString::null;
 
-        KProcIO *proc=new KProcIO();
-	*proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--status-fd=2"<<"--command-fd=0";
-	for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it ) 
+        KProcIO *proc=new KProcIO(QTextCodec::codecForLocale());
+	*proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--status-fd=2"<<"--command-fd=0"<<"--utf8-strings";
+	for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it )
        		if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
 
                 *proc<<"--output"<<QFile::encodeName(destUrl.path());
-		
+
 		if (!symetrical) {
 		*proc<<"-e";
 		for ( QStringList::Iterator it = encryptKeys.begin(); it != encryptKeys.end(); ++it )
        		*proc<<"--recipient"<< *it;
         	} else  ////////////   symetrical encryption, prompt for password
                 *proc<<"-c";
-		
+
 		*proc<<QFile::encodeName(srcUrl.path());
 
         /////////  when process ends, update dialog infos
@@ -167,19 +167,19 @@ void KgpgInterface::KgpgDecryptFile(KURL srcUrl,KURL destUrl,QStringList Options
 	decryptUrl=srcUrl.path();
         userIDs=QString::null;
         anonymous=false;
-	
-        KProcIO *proc=new KProcIO();
 
-                *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--status-fd=2"<<"--command-fd=0";
+        KProcIO *proc=new KProcIO(QTextCodec::codecForLocale());
+
+                *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--status-fd=2"<<"--command-fd=0"<<"--utf8-strings";
 
 		for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it )
        		if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
 
 		if (!destUrl.fileName().isEmpty()) // a filename was entered
 				*proc<<"-o"<<QFile::encodeName(destUrl.path());
-        
+
                 *proc<<"-d"<<QFile::encodeName(srcUrl.path());
-        
+
         QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(decryptfin(KProcess *)));
         QObject::connect(proc,SIGNAL(readReady(KProcIO *)),this,SLOT(readdecprocess(KProcIO *)));
         proc->start(KProcess::NotifyOnExit,true);
@@ -221,7 +221,7 @@ void KgpgInterface::readdecprocess(KProcIO *p)
                                 if ((step<3) && (!anonymous))
                                         passdlgmessage=i18n("<b>Bad passphrase</b>. You have %1 tries left.<br>").arg(step);
 
-                                passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8bis(userIDs));
+                                passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(userIDs);
                                 int code=KPasswordDialog::getPassword(passphrase,passdlgmessage);
                                 if (code!=QDialog::Accepted) {
                                         delete p;
@@ -252,22 +252,22 @@ void KgpgInterface::KgpgEncryptText(QString text,QStringList userIDs, QStringLis
 	QTextCodec *codec =QTextCodec::codecForLocale ();
 	if (codec->canEncode(text)) txtToEncrypt=text;
 	else txtToEncrypt=text.utf8();
-	
-        KProcIO *proc=new KProcIO();
-        *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=1";
-        
+
+        KProcIO *proc=new KProcIO(QTextCodec::codecForLocale());
+        *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=1"<<"--utf8-strings";
+
 	for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it )
        		if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
-	
+
 	if (!userIDs.isEmpty())
 	{
         *proc<<"-e";
 	for ( QStringList::Iterator it = userIDs.begin(); it != userIDs.end(); ++it )
        		*proc<<"--recipient"<< *it;
 	}
-	else 
+	else
 	  *proc<<"-c";
-	
+
         /////////  when process ends, update dialog infos
 
         QObject::connect(proc, SIGNAL(processExited(KProcess *)),this,SLOT(txtencryptfin(KProcess *)));
@@ -280,7 +280,7 @@ void KgpgInterface::KgpgEncryptText(QString text,QStringList userIDs, QStringLis
 void KgpgInterface::txtencryptfin(KProcess *)
 {
         if (!message.isEmpty())
-                emit txtencryptionfinished(QString::fromUtf8(message.ascii()));
+                emit txtencryptionfinished(message);
         else
                 emit txtencryptionfinished(QString::null);
 }
@@ -307,7 +307,7 @@ void KgpgInterface::txtreadencprocess(KProcIO *p)
                   return;
                 }
               p->writeStdin(passphrase,true);
-            } 
+            }
 	    else
 		if (!required.startsWith("[GNUPG:]")) message+=required+"\n";
         }
@@ -319,8 +319,8 @@ void KgpgInterface::txtreadencprocess(KProcIO *p)
 void KgpgInterface::KgpgDecryptText(QString text,QStringList Options)
 {
   gpgOutput=QString::null;
-  log=QString::null;	
-  
+  log=QString::null;
+
   message=QString::null;
   userIDs=QString::null;
   step=3;
@@ -329,7 +329,7 @@ void KgpgInterface::KgpgDecryptText(QString text,QStringList Options)
   decok=false;
   badmdc=false;
   KProcess *proc=new KProcess();
-  *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=2"<<"--no-batch";
+  *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=2"<<"--no-batch"<<"--utf8-strings";
   for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it )
 	  if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
   *proc<<"-d";
@@ -340,15 +340,15 @@ void KgpgInterface::KgpgDecryptText(QString text,QStringList Options)
   connect(proc, SIGNAL(receivedStdout(KProcess *, char *, int)),this, SLOT(getOutput(KProcess *, char *, int)));
   connect(proc, SIGNAL(receivedStderr(KProcess *, char *, int)),this, SLOT(getCmdOutput(KProcess *, char *, int)));
   proc->start(KProcess::NotifyOnExit,KProcess::All);
-  proc->writeStdin(text.ascii(),text.length());
+  proc->writeStdin(text.utf8(), text.length());
 }
 
 void KgpgInterface::txtdecryptfin(KProcess *)
 {
-if ((decok) && (!badmdc)) 
+if ((decok) && (!badmdc))
 emit txtdecryptionfinished(message);
 
-else if (badmdc) 
+else if (badmdc)
 {
 KMessageBox::sorry(0,i18n("Bad MDC detected. The encrypted text has been manipulated."));
 emit txtdecryptionfailed(log);
@@ -360,30 +360,30 @@ emit txtdecryptionfailed(log);
 
 void KgpgInterface::getOutput(KProcess *, char *data, int )
 {
-	message.append(data);
+	message.append(QString::fromUtf8(data));
 }
 
 
 void KgpgInterface::getCmdOutput(KProcess *p, char *data, int )
 {
-  gpgOutput.append(data);
+  gpgOutput.append(QString::fromUtf8(data));
   log.append(data);
 
   int pos;
   while ((pos=gpgOutput.find("\n"))!=-1)
-  {	
+  {
 	QString required=gpgOutput.left(pos);
 	gpgOutput.remove(0,pos+2);
-			
+
 	if (required.find("USERID_HINT",0,false)!=-1)
 		updateIDs(required);
-	
+
 	if (required.find("ENC_TO")!=-1)
 	{
 		if (required.find("0000000000000000")!=-1)
 			anonymous=true;
 	}
-		
+
 	if (required.find("GET_")!=-1)
 	{
 		if ((required.find("passphrase.enter")!=-1))
@@ -396,7 +396,7 @@ void KgpgInterface::getCmdOutput(KProcess *p, char *data, int )
 				passdlgmessage=i18n("<b>No user id found</b>. Trying all secret keys.<br>");
 			if ((step<3) && (!anonymous))
 				passdlgmessage=i18n("<b>Bad passphrase</b>. You have %1 tries left.<br>").arg(step);
-			passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8bis(userIDs));
+			passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(userIDs);
 			int code=KPasswordDialog::getPassword(passphrase,passdlgmessage);
 			if (code!=QDialog::Accepted)
 			{
@@ -416,7 +416,7 @@ void KgpgInterface::getCmdOutput(KProcess *p, char *data, int )
 			p->closeStdin();
 		}
 	}
-	
+
 	if (required.find("BEGIN_DECRYPTION")!=-1)
 	{
 		p->closeStdin();
@@ -440,10 +440,10 @@ void KgpgInterface::KgpgSignText(QString text,QString userIDs, QStringList Optio
 	QTextCodec *codec =QTextCodec::codecForLocale ();
 	if (codec->canEncode(text)) txtprocess=text;
 	else txtprocess=text.utf8();
-	
-        KProcIO *proc=new KProcIO();
-        *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=1";
-        
+
+        KProcIO *proc=new KProcIO(QTextCodec::codecForLocale());
+        *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=1"<<"--utf8-strings";
+
 	for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it )
 		if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
         *proc<<"--clearsign"<<"-u"<<userIDs;
@@ -481,17 +481,17 @@ void KgpgInterface::txtsignprocess(KProcIO *p)
         QString required;
         while (p->readln(required,true)!=-1) {
 //	kdDebug(2100)<<"SIGNING: "<<required<<endl;
-	
+
 	if (required.find("USERID_HINT",0,false)!=-1)
         updateIDs(required);
-	
+
 	if (required.find("GOOD_PASSPHRASE")!=-1)
 	{
 	p->writeStdin(message,true);
 	message=QString::null;
 	p->closeWhenDone();
 	}
-	
+
 	if ((required.find("passphrase.enter")!=-1))
             {
 	      if (step>1) step--;
@@ -502,15 +502,15 @@ void KgpgInterface::txtsignprocess(KProcIO *p)
               QString passdlgmessage;
               if (step<3)
               passdlgmessage=i18n("<b>Bad passphrase</b>. You have %1 tries left.<br>").arg(step);
-              passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8bis(userIDs));
+              passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(userIDs);
               int code=KPasswordDialog::getPassword(passphrase,passdlgmessage);
 	      if (code!=QDialog::Accepted)
                 {
                   delete p;
                   return;
                 }
-              p->writeStdin(passphrase,true);		
-            } 
+              p->writeStdin(passphrase,true);
+            }
 	    else
 		if (!required.startsWith("[GNUPG:]")) message+=required+"\n";
         }
@@ -521,7 +521,7 @@ void KgpgInterface::txtsignprocess(KProcIO *p)
 
 void KgpgInterface::KgpgDecryptFileToText(KURL srcUrl,QStringList Options)
 {
-        
+
   message=QString::null;
   userIDs=QString::null;
   step=3;
@@ -531,7 +531,7 @@ decok=false;
 badmdc=false;
 
   KProcess *proc=new KProcess();
-  *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=2"<<"--no-batch"<<"-o"<<"-";
+  *proc<<"gpg"<<"--no-tty"<<"--utf8-strings"<<"--no-secmem-warning"<<"--command-fd=0"<<"--status-fd=2"<<"--no-batch"<<"-o"<<"-";
       	for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it ) {
        		if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
     		}
@@ -557,16 +557,16 @@ void KgpgInterface::KgpgVerifyText(QString text)
 		signmiss=false;
 		signID=QString::null;
 		message=QString::null;
-		 KProcIO *verifyproc=new KProcIO();
-        	*verifyproc<<"gpg"<<"--no-secmem-warning"<<"--status-fd=2"<<"--command-fd=0"<<"--verify";
+		 KProcIO *verifyproc=new KProcIO(QTextCodec::codecForLocale());
+         *verifyproc<<"gpg"<<"--no-secmem-warning"<<"--status-fd=2"<<"--command-fd=0"<<"--utf8-strings"<<"--verify";
         	connect(verifyproc, SIGNAL(processExited(KProcess *)),this, SLOT(slotverifyresult(KProcess *)));
         	connect(verifyproc, SIGNAL(readReady(KProcIO *)),this, SLOT(slotverifyread(KProcIO *)));
         	verifyproc->start(KProcess::NotifyOnExit,true);
 		verifyproc->writeStdin (text);
 		verifyproc->closeWhenDone();
-}		
-		
-		
+}
+
+
 void KgpgInterface::slotverifyresult(KProcess*)
 {
 if (signmiss) emit missingSignature(signID);
@@ -590,11 +590,11 @@ QString required;
 	     userName=checkForUtf8(userName);
      signID=i18n("<qt>Good signature from:<br><b>%1</b><br>Key ID: %2</qt>").arg(userName).arg("0x"+required.section(" ",1,1).right(8));
      }
-     if (required.startsWith("BADSIG")) 
+     if (required.startsWith("BADSIG"))
      {
      signID=i18n("<qt><b>Bad signature</b> from:<br>%1<br>Key ID: %2<br><br><b>Text is corrupted.</b></qt>").arg(required.section(" ",2,-1).replace(QRegExp("<"),"&lt;")).arg("0x"+required.section(" ",1,1).right(8));
      }
-     if (required.startsWith("NO_PUBKEY")) 
+     if (required.startsWith("NO_PUBKEY"))
      {
      signID="0x"+required.section(" ",1,1).right(8);
      signmiss=true;
@@ -696,9 +696,9 @@ void KgpgInterface::KgpgSignFile(QString keyID,KURL srcUrl,QStringList Options)
         message=QString::null;
         step=3;
         /////////////       create gpg command
-        KProcIO *proc=new KProcIO();
+        KProcIO *proc=new KProcIO(QTextCodec::codecForLocale());
         keyID=keyID.stripWhiteSpace();
-        *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--status-fd=2"<<"--command-fd=0"<<"-u"<<keyID.local8Bit();
+        *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--utf8-strings"<<"--status-fd=2"<<"--command-fd=0"<<"-u"<<keyID.local8Bit();
 		for ( QStringList::Iterator it = Options.begin(); it != Options.end(); ++it )
        		if (!QFile::encodeName(*it).isEmpty()) *proc<< QFile::encodeName(*it);
 
@@ -728,7 +728,7 @@ void KgpgInterface::readsignprocess(KProcIO *p)
 {
         QString required;
         while (p->readln(required,true)!=-1) {
-                if (required.find("USERID_HINT",0,false)!=-1) 
+                if (required.find("USERID_HINT",0,false)!=-1)
 		updateIDs(required);
 
                 if (required.find("GET_")!=-1) {
@@ -741,7 +741,7 @@ void KgpgInterface::readsignprocess(KProcIO *p)
                                 QString passdlgmessage;
                                 if (step<3)
                                         passdlgmessage=i18n("<b>Bad passphrase</b>. you have %1 tries left.<br>").arg(step);
-                                passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(checkForUtf8bis(userIDs));
+                                passdlgmessage+=i18n("Enter passphrase for <b>%1</b>").arg(userIDs);
                                 int code=KPasswordDialog::getPassword(passphrase,passdlgmessage);
                                 if (code!=QDialog::Accepted) {
                                         delete p;
@@ -771,9 +771,9 @@ void KgpgInterface::KgpgVerifyFile(KURL sigUrl,KURL srcUrl)
 	signID=QString::null;
 	signmiss=false;
         /////////////       create gpg command
-        KProcIO *proc=new KProcIO();
+        KProcIO *proc=new KProcIO(QTextCodec::codecForLocale());
         file=sigUrl;
-        *proc<<"gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--status-fd=2"<<"--verify";
+        *proc<<"gpg"<<"--no-tty"<<"--utf8-strings"<<"--no-secmem-warning"<<"--status-fd=2"<<"--verify";
         if (!srcUrl.isEmpty())
                 *proc<<QFile::encodeName(srcUrl.path());
         *proc<<QFile::encodeName(sigUrl.path());
@@ -801,12 +801,12 @@ QString required;
     {
     signID=i18n("<qt>Good signature from:<br><b>%1</b><br>Key ID: %2</qt>").arg(required.section(" ",2,-1).replace(QRegExp("<"),"&lt;")).arg("0x"+required.section(" ",1,1).right(8));
     }
-    if (required.startsWith("BADSIG")) 
+    if (required.startsWith("BADSIG"))
     {
     signID=i18n("<qt><b>BAD signature</b> from:<br> %1<br>Key id: %2<br><br>"
                              "<b>The file is corrupted!</b></qt>").arg(required.section(" ",2,-1).replace(QRegExp("<"),"&lt;")).arg("0x"+required.section(" ",1,1).right(8));
     }
-    if (required.startsWith("NO_PUBKEY")) 
+    if (required.startsWith("NO_PUBKEY"))
     {
     signmiss=true;
     signID="0x"+required.section(" ",1,1).right(8);
@@ -822,7 +822,7 @@ QString required;
 void KgpgInterface::verifyfin(KProcess *)
 {
     if (!signmiss) {
-        if (signID.isEmpty()) signID=i18n("No signature found.");    
+        if (signID.isEmpty()) signID=i18n("No signature found.");
         (void) new KDetailedInfo(0,"verify_result",signID,message);
     }
     else {
@@ -845,17 +845,17 @@ void KgpgInterface::KgpgSignKey(QString keyID,QString signKeyID,QString signKeyM
         konsSignKey=signKeyID;
         konsKeyID=keyID;
         errMessage=QString::null;
-        if (checkuid(keyID)>0) 
+        if (checkuid(keyID)>0)
 	{
                 openSignConsole();
 		return;
 	}
-	
+
         signSuccess=0;
         step=1;
         output=QString::null;
-        KProcIO *conprocess=new KProcIO();
-        *conprocess<<"gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--command-fd=0"<<"--status-fd=2"<<"-u"<<signKeyID;
+        KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
+        *conprocess<<"gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--utf8-strings"<<"--command-fd=0"<<"--status-fd=2"<<"-u"<<signKeyID;
         *conprocess<<"--edit-key"<<keyID;
 	if (local) *conprocess<<"lsign";
 	else *conprocess<<"sign";
@@ -872,9 +872,9 @@ void KgpgInterface::sigprocess(KProcIO *p)
         {
 
                 output+=required+"\n";
-                if (required.find("USERID_HINT",0,false)!=-1) 
+                if (required.find("USERID_HINT",0,false)!=-1)
 		updateIDs(required);
-		
+
                 if (signSuccess==4) {
                         if (required.find("GET_")!=-1)
                                 p->writeStdin("quit");
@@ -899,15 +899,16 @@ void KgpgInterface::sigprocess(KProcIO *p)
                         p->writeStdin("Y");
                         required=QString::null;
                 }
-		
+
 		if (required.find("sign_all.okay")!=-1) {
                         p->writeStdin("Y");
                         required=QString::null;
                 }
-		
+
                 if (required.find("passphrase.enter")!=-1) {
                         QCString signpass;
-                        int code=KPasswordDialog::getPassword(signpass,i18n("<qt>%1 Enter passphrase for <b>%2</b>:</qt>").arg(errMessage).arg(checkForUtf8bis(userIDs)));
+                        int code=KPasswordDialog::getPassword(signpass,i18n("<qt>%1 Enter passphrase for <b>%2</b>:</qt>")
+                                                              .arg(errMessage).arg(userIDs));
                         if (code!=QDialog::Accepted) {
                                 signSuccess=4;  /////  aborted by user mode
                                 required=QString::null;
@@ -984,7 +985,7 @@ void KgpgInterface::KgpgDelSignature(QString keyID,QString signKeyID)
         message=signKeyID.remove(0,2);
         deleteSuccess=false;
         step=0;
-        
+
         FILE *fp;
         QString encResult;
         char buffer[200];
@@ -1003,8 +1004,8 @@ void KgpgInterface::KgpgDelSignature(QString keyID,QString signKeyID)
                         signb++;
         }
         pclose(fp);
-        KProcIO *conprocess=new KProcIO();
-        *conprocess<<"gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--command-fd=0"<<"--status-fd=2";
+        KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
+        *conprocess<<"gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--utf8-strings"<<"--command-fd=0"<<"--status-fd=2";
         *conprocess<<"--edit-key"<<keyID<<"uid 1"<<"delsig";
         QObject::connect(conprocess,SIGNAL(readReady(KProcIO *)),this,SLOT(delsigprocess(KProcIO *)));
         QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(delsignover(KProcess *)));
@@ -1012,7 +1013,7 @@ void KgpgInterface::KgpgDelSignature(QString keyID,QString signKeyID)
 }
 
 
-void KgpgInterface::delsigprocess(KProcIO *p)//ess *p,char *buf, int buflen)
+void KgpgInterface::delsigprocess(KProcIO *p)
 {
 
         QString required=QString::null;
@@ -1080,8 +1081,8 @@ void KgpgInterface::KgpgKeyExpire(QString keyID,QDate date,bool unlimited)
         else
                 expirationDelay=QDate::currentDate().daysTo(date);
         output=QString::null;
-        KProcIO *conprocess=new KProcIO();
-        *conprocess<<"gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--command-fd=0"<<"--status-fd=2";
+        KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
+        *conprocess<<"gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--command-fd=0"<<"--status-fd=2"<<"--utf8-strings";
         *conprocess<<"--edit-key"<<keyID<<"expire";
         QObject::connect(conprocess,SIGNAL(readReady(KProcIO *)),this,SLOT(expprocess(KProcIO *)));
         QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(expover(KProcess *)));
@@ -1096,9 +1097,9 @@ void KgpgInterface::expprocess(KProcIO *p)
         while (p->readln(required,true)!=-1) {
                 output+=required+"\n";
 
-                if (required.find("USERID_HINT",0,false)!=-1) 
+                if (required.find("USERID_HINT",0,false)!=-1)
 		updateIDs(required);
-		
+
                 if ((required.find("GOOD_PASSPHRASE")!=-1)) {
                         expSuccess=3;
                         step=2;
@@ -1111,7 +1112,7 @@ void KgpgInterface::expprocess(KProcIO *p)
 
                 if (required.find("passphrase.enter")!=-1) {
                         QCString signpass;
-                        int code=KPasswordDialog::getPassword(signpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8bis(userIDs)));
+                        int code=KPasswordDialog::getPassword(signpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(userIDs));
                         if (code!=QDialog::Accepted) {
                                 expSuccess=3;  /////  aborted by user mode
                                 p->writeStdin("quit");
@@ -1172,10 +1173,10 @@ void KgpgInterface::KgpgTrustExpire(QString keyID,int keyTrust)
 {
 	trustValue=keyTrust+1;
 /*	Don't know=1; Do NOT trust=2; Marginally=3; Fully=4; Ultimately=5;   */
-	
+
         output=QString::null;
-        KProcIO *conprocess=new KProcIO();
-        *conprocess<<"gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--command-fd=0"<<"--status-fd=2";
+        KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
+        *conprocess<<"gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--command-fd=0"<<"--status-fd=2"<<"--utf8-strings";
         *conprocess<<"--edit-key"<<keyID<<"trust";
         QObject::connect(conprocess,SIGNAL(readReady(KProcIO *)),this,SLOT(trustprocess(KProcIO *)));
         QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(trustover(KProcess *)));
@@ -1230,8 +1231,8 @@ void KgpgInterface::KgpgChangePass(QString keyID)
         step=1;
         output=QString::null;
         message=QString::null;
-        KProcIO *conprocess=new KProcIO();
-        *conprocess<<"gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--no-use-agent"<<"--command-fd=0"<<"--status-fd=2";
+        KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
+        *conprocess<<"gpg"<<"--no-secmem-warning"<<"--no-tty"<<"--no-use-agent"<<"--command-fd=0"<<"--status-fd=2"<<"--utf8-strings";
         *conprocess<<"--edit-key"<<keyID<<"passwd";
         QObject::connect(conprocess,SIGNAL(readReady(KProcIO *)),this,SLOT(passprocess(KProcIO *)));
         QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(passover(KProcess *)));
@@ -1249,7 +1250,7 @@ void KgpgInterface::passprocess(KProcIO *p)
                 if (required.find("USERID_HINT",0,false)!=-1)
 		updateIDs(required);
 
-                if ((step>2) && (required.find("keyedit.prompt")!=-1)) {			
+                if ((step>2) && (required.find("keyedit.prompt")!=-1)) {
 			if (step==3)
 			{
 			emit passwordChanged();
@@ -1274,7 +1275,8 @@ void KgpgInterface::passprocess(KProcIO *p)
 
                         if (step==1) {
                                 QCString passphrase;
-                                int code=KPasswordDialog::getPassword(passphrase,i18n("<qt>%1 Enter passphrase for <b>%2</b></qt>").arg(message).arg(checkForUtf8bis(userIDs)));
+                                int code=KPasswordDialog::getPassword(passphrase,i18n("<qt>%1 Enter passphrase for <b>%2</b></qt>")
+                                                                      .arg(message).arg(userIDs));
                                 if (code!=QDialog::Accepted) {
                                         p->writeStdin("quit");
                                         //				 p->closeWhenDone();
@@ -1328,8 +1330,8 @@ void KgpgInterface::passover(KProcess *)
 QString KgpgInterface::getKey(QStringList IDs, bool attributes)
 {
         keyString=QString::null;
-        KProcIO *proc=new KProcIO();
-        *proc<< "gpg"<<"--no-tty"<<"--no-secmem-warning";
+        KProcIO *proc=new KProcIO(QTextCodec::codecForLocale());
+        *proc<< "gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--utf8-strings";
         *proc<<"--export"<<"--armor";
         if (!attributes)
                 *proc<<"--export-options"<<"no-include-attributes";
@@ -1358,8 +1360,8 @@ void KgpgInterface::importKeyURL(KURL url)
 
         if( KIO::NetAccess::download( url, tempKeyFile,0) ) {
                 message=QString::null;
-                KProcIO *conprocess=new KProcIO();
-                *conprocess<< "gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--status-fd=2"<<"--import";
+                KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
+                *conprocess<< "gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--status-fd=2"<<"--utf8-strings"<<"--import";
                 *conprocess<<"--allow-secret-key-import";
                 *conprocess<<tempKeyFile;
                 QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(importURLover(KProcess *)));
@@ -1372,7 +1374,7 @@ void KgpgInterface::importKey(QString keystr)
 {
         /////////////      import a key
         message=QString::null;
-        KProcIO *conprocess=new KProcIO();
+        KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
         *conprocess<< "gpg"<<"--no-tty"<<"--no-secmem-warning"<<"--status-fd=2"<<"--import";
         *conprocess<<"--allow-secret-key-import";
         QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(importover(KProcess *)));
@@ -1397,12 +1399,12 @@ kdDebug(2100)<<"Importing is over"<<endl;
 		importedKeys<<parsedOutput.section("\n",0,0).stripWhiteSpace();
 		importedKeysIds<<parsedOutput.stripWhiteSpace().section(' ',0,0);
         }
-	
+
 
         if (message.find("IMPORT_RES")!=-1) {
                 parsedOutput=message.section("IMPORT_RES",-1,-1).stripWhiteSpace();
 		messageList=QStringList::split(" ",parsedOutput,true);
-                	
+
                 resultMessage=i18n("<qt>%n key processed.<br></qt>","<qt>%n keys processed.<br></qt>",messageList[0].toULong());
                 if (messageList[4]!="0")
                         resultMessage+=i18n("<qt>One key unchanged.<br></qt>","<qt>%n keys unchanged.<br></qt>",messageList[4].toULong());
@@ -1431,18 +1433,18 @@ kdDebug(2100)<<"Importing is over"<<endl;
                         resultMessage+=i18n("<qt>One secret key not imported.<br></qt>","<qt>%n secret keys not imported.<br></qt>",messageList[12].toULong());
                 if (messageList[2]!="0")
                         resultMessage+=i18n("<qt><b>One key imported:</b><br></qt>","<qt><b>%n keys imported:</b><br></qt>",messageList[2].toULong());
-			
+
 		if (secretImport) resultMessage+=i18n("<qt><br><b>You have imported a secret key.</b> <br>"
 									"Please note that imported secret keys are not trusted by default.<br>"
 									"To fully use this secret key for signing and encryption, you must edit the key (double click on it) and set its trust to Full or Ultimate.</qt>");
         } else
                 resultMessage=i18n("No key imported... \nCheck detailed log for more infos");
-		
+
 	if (messageList[8]!="0") importedKeysIds="ALL";
 	if ((messageList[9]!="0") && (importedKeysIds.isEmpty())) // orphaned secret key imported
 	emit refreshOrphaned();
         emit importfinished(importedKeysIds);
-	
+
 	(void) new KDetailedInfo(0,"import_result",resultMessage,message,importedKeys);
 }
 
@@ -1475,8 +1477,8 @@ uidEmail=email;
 output=QString::null;
 addSuccess=true;
 
-        KProcIO *conprocess=new KProcIO();
-        *conprocess<< "gpg"<<"--no-tty"<<"--status-fd=2"<<"--command-fd=0";
+        KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
+        *conprocess<< "gpg"<<"--no-tty"<<"--status-fd=2"<<"--command-fd=0"<<"--utf8-strings";
         *conprocess<<"--edit-key"<<keyID<<"adduid";
         QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(adduidover(KProcess *)));
         QObject::connect(conprocess, SIGNAL(readReady(KProcIO *)),this, SLOT(adduidprocess(KProcIO *)));
@@ -1494,19 +1496,19 @@ void KgpgInterface::adduidprocess(KProcIO *p)
         QString required=QString::null;
         while (p->readln(required,true)!=-1) {
                 output+=required+"\n";
-                if (required.find("USERID_HINT",0,false)!=-1) 
+                if (required.find("USERID_HINT",0,false)!=-1)
 		updateIDs(required);
 
                 if (required.find("keygen.name")!=-1)  {
                         p->writeStdin(uidName);
                         required=QString::null;
                 }
-		
+
 		if (required.find("keygen.email")!=-1)  {
                         p->writeStdin(uidEmail);
                         required=QString::null;
                 }
-		
+
 		if (required.find("keygen.comment")!=-1)  {
                         p->writeStdin(uidComment);
                         required=QString::null;
@@ -1514,9 +1516,10 @@ void KgpgInterface::adduidprocess(KProcIO *p)
 
                 if (required.find("passphrase.enter")!=-1) {
                         QCString delpass;
-                        int code=KPasswordDialog::getPassword(delpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8bis(userIDs)));
+                        int code=KPasswordDialog::getPassword(delpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>")
+                                                              .arg(userIDs));
                         if (code!=QDialog::Accepted) {
-                                //deleteSuccess=false;
+                                //addSuccess=false;
                                 p->writeStdin("quit");
                                 p->closeWhenDone();
                                 return;
@@ -1537,7 +1540,6 @@ void KgpgInterface::adduidprocess(KProcIO *p)
                         addSuccess=false;  /////  switching to console mode
                         p->writeStdin("quit");
                         p->closeWhenDone();
-
                 }
         }
 }
@@ -1559,7 +1561,7 @@ output=QString::null;
 photoCount=1;
 userIDs=keyID;
 
-        KProcIO *conprocess=new KProcIO();
+        KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
         *conprocess<< "gpg"<<"--no-tty"<<"--status-fd=2"<<"--command-fd=0";
         *conprocess<<"--with-colon"<<"--list-keys"<<keyID;
         QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(photoreadover(KProcess *)));
@@ -1591,8 +1593,8 @@ KTempFile *kgpginfotmp=new KTempFile();
                 kgpginfotmp->setAutoDelete(true);
                 QString pgpgOutput="cp %i "+kgpginfotmp->name();
 
-KProcIO *conprocess=new KProcIO();
-        *conprocess<< "gpg"<<"--no-tty"<<"--status-fd=2"<<"--command-fd=0";
+KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
+        *conprocess<< "gpg"<<"--no-tty"<<"--status-fd=2"<<"--command-fd=0"<<"--utf8-strings";
         *conprocess<<"--photo-viewer"<<QFile::encodeName(pgpgOutput)<<"--edit-key"<<userIDs<<"uid"<<QString::number(uid)<<"showphoto";
         conprocess->start(KProcess::Block);
 	if (kgpginfotmp->file()->size()>0)
@@ -1608,8 +1610,8 @@ void KgpgInterface::KgpgDeletePhoto(QString keyID,QString uid)
 {
 	delSuccess=true;
 	output=QString::null;
-        KProcIO *conprocess=new KProcIO();
-        *conprocess<< "gpg"<<"--no-tty"<<"--status-fd=2"<<"--command-fd=0";
+        KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
+        *conprocess<< "gpg"<<"--no-tty"<<"--status-fd=2"<<"--command-fd=0"<<"--utf8-strings";
         *conprocess<<"--edit-key"<<keyID<<"uid"<<uid<<"deluid";
         QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(delphotoover(KProcess *)));
         QObject::connect(conprocess, SIGNAL(readReady(KProcIO *)),this, SLOT(delphotoprocess(KProcIO *)));
@@ -1637,7 +1639,7 @@ void KgpgInterface::delphotoprocess(KProcIO *p)
 
                 if (required.find("passphrase.enter")!=-1) {
                         QCString delpass;
-                        int code=KPasswordDialog::getPassword(delpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8bis(userIDs)));
+                        int code=KPasswordDialog::getPassword(delpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(userIDs));
                         if (code!=QDialog::Accepted) {
                                 //deleteSuccess=false;
                                 p->writeStdin("quit");
@@ -1671,8 +1673,8 @@ void KgpgInterface::KgpgAddPhoto(QString keyID,QString imagePath)
 photoUrl=imagePath;
 output=QString::null;
 addSuccess=true;
-        KProcIO *conprocess=new KProcIO();
-        *conprocess<< "gpg"<<"--no-tty"<<"--status-fd=2"<<"--command-fd=0";
+        KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
+        *conprocess<< "gpg"<<"--no-tty"<<"--status-fd=2"<<"--command-fd=0"<<"--utf8-strings";
         *conprocess<<"--edit-key"<<keyID<<"addphoto";
         QObject::connect(conprocess, SIGNAL(processExited(KProcess *)),this, SLOT(addphotoover(KProcess *)));
         QObject::connect(conprocess, SIGNAL(readReady(KProcIO *)),this, SLOT(addphotoprocess(KProcIO *)));
@@ -1692,16 +1694,16 @@ void KgpgInterface::addphotoprocess(KProcIO *p)
                 output+=required+"\n";
                 if (required.find("USERID_HINT",0,false)!=-1)
 		updateIDs(required);
-		
+
                 if (required.find("photoid.jpeg.add")!=-1)  {
                         p->writeStdin(photoUrl);
                         required=QString::null;
                 }
-		
+
 		if (required.find("photoid.jpeg.size")!=-1)  {
 			if (KMessageBox::questionYesNo(0,i18n("This image is very large. Use it anyway?"), QString::null, i18n("Use Anyway"), i18n("Do Not Use"))==KMessageBox::Yes)
                         p->writeStdin("Yes");
-			else 
+			else
 			{
 			p->writeStdin("No");
 			p->writeStdin("");
@@ -1712,7 +1714,7 @@ void KgpgInterface::addphotoprocess(KProcIO *p)
 
                 if (required.find("passphrase.enter")!=-1) {
                         QCString delpass;
-                        int code=KPasswordDialog::getPassword(delpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8bis(userIDs)));
+                        int code=KPasswordDialog::getPassword(delpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(userIDs));
                         if (code!=QDialog::Accepted) {
                                 //deleteSuccess=false;
                                 p->writeStdin("quit");
@@ -1750,8 +1752,8 @@ void KgpgInterface::KgpgRevokeKey(QString keyID,QString revokeUrl,int reason,QSt
         revokeDescription=description;
         certificateUrl=revokeUrl;
         output=QString::null;
-        KProcIO *conprocess=new KProcIO();
-        *conprocess<< "gpg"<<"--no-tty"<<"--status-fd=2"<<"--logger-fd=2"<<"--command-fd=0";
+        KProcIO *conprocess=new KProcIO(QTextCodec::codecForLocale());
+        *conprocess<< "gpg"<<"--no-tty"<<"--status-fd=2"<<"--logger-fd=2"<<"--command-fd=0"<<"--utf8-strings";
         if (!revokeUrl.isEmpty())
                 *conprocess<<"-o"<<revokeUrl;
         *conprocess<<"--gen-revoke"<<keyID;
@@ -1782,7 +1784,7 @@ void KgpgInterface::revokeprocess(KProcIO *p)
 
                 if (required.find("USERID_HINT",0,false)!=-1)
 		updateIDs(required);
-		
+
                 if ((required.find("GOOD_PASSPHRASE")!=-1))
                         revokeSuccess=true;
 
@@ -1798,7 +1800,7 @@ void KgpgInterface::revokeprocess(KProcIO *p)
 
                 if (required.find("passphrase.enter")!=-1) {
                         QCString signpass;
-                        int code=KPasswordDialog::getPassword(signpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(checkForUtf8bis(userIDs)));
+                        int code=KPasswordDialog::getPassword(signpass,i18n("<qt>Enter passphrase for <b>%1</b>:</qt>").arg(userIDs));
                         if (code!=QDialog::Accepted) {
                                 expSuccess=3;  /////  aborted by user mode
                                 p->writeStdin("quit");
@@ -2129,7 +2131,6 @@ QString KgpgInterface::checkForUtf8bis(QString txt)
 
 QString KgpgInterface::checkForUtf8(QString txt)
 {
-
         //    code borrowed from gpa
         const char *s;
 
@@ -2153,10 +2154,12 @@ QString KgpgInterface::checkForUtf8(QString txt)
                 str[0] = (char) QString( txt.mid( idx + 2, 2 ) ).toShort( 0, 16 );
                 txt.replace( idx, 4, str );
         }
-//	if (!strchr (txt.ascii(), 0xc3))
-                return QString::fromUtf8(txt.ascii());
-//        else
-//                return QString::fromUtf8(QString::fromUtf8(txt.ascii()).ascii());  // perform Utf8 twice, or some keys display badly
+        if (!strchr (txt.ascii(), 0xc3))
+            return QString::fromUtf8(txt.ascii());
+        else
+            return QString::fromUtf8(QString::fromUtf8(txt.ascii()).ascii());  // perform Utf8 twice, or some keys display badly
+
+        return txt;
 }
 
 
