@@ -151,7 +151,9 @@ public slots:
 	void KgpgSignText(QString text,QString userIDs, QStringList Options);
 
         static QString getGpgSetting(QString name,QString configFile);
+	static QString getGpgMultiSetting(QString name,QString configFile);
         static void setGpgSetting(QString name,QString ID,QString url);
+	static void setGpgMultiSetting(QString name,QStringList values,QString url);
         static bool getGpgBoolSetting(QString name,QString configFile);
 	static void setGpgBoolSetting(QString name,bool enable,QString url);
         static QStringList getGpgGroupNames(QString configFile);
@@ -262,7 +264,6 @@ private slots:
 	void txtsignprocess(KProcIO *p);
 	void txtsignfin(KProcess *);
 
-        //void txtreaddecprocess(KProcIO *p);
         //void txtdecryptfin(KProcess *);
 
 
