@@ -26,6 +26,7 @@
 #include "kbufferlayout.h"
 #include "kbufferranges.h"
 #include "helper.h"
+#include "kcharcodec.h"
 
 using namespace KHE;
 
@@ -33,9 +34,9 @@ static const unsigned int StartsBefore = 1;
 static const unsigned int EndsLater = 2;
 static const char EmptyByte = ' ';
 
-static const int DefaultCursorWidth = 2;
-static const int DefaultByteSpacingWidth = 3;
-static const int DefaultGroupSpacingWidth = 9;
+static const KPixelX DefaultCursorWidth = 2;
+static const KPixelX DefaultByteSpacingWidth = 3;
+static const KPixelX DefaultGroupSpacingWidth = 9;
 static const int DefaultNoOfGroupedBytes = 4;
 
 KBufferColumn::KBufferColumn( KColumnsView *CV, KDataBuffer *B, KBufferLayout *L, KBufferRanges *R )
@@ -345,43 +346,26 @@ KPixelXs KBufferColumn::relWideXPixelsOfPos( KSection Positions ) const
 }
 
 
-void KBufferColumn::preparePainting( KPixelX cx, KPixelX cw )
+void KBufferColumn::preparePainting( KPixelXs Xs )
 {
+  Xs.restrictTo( XSpan );
   // translate
-  cx -= x();
+  Xs.moveBy( -x() );
 
-  // calculating the most right relative x to paint
-  KPixelX LastX = cx + cw - 1;
-  if( LastX >= width() )
-    LastX = width()-1;
 
-  // calculating the most left relative x to paint
-  PaintX = cx > 0 ? cx : 0;
-  // calculating the width
-  PaintW = LastX - PaintX + 1;
+  // store the values
+  PaintX = Xs.start();
+  PaintW = Xs.width();
 
   // get line positions to paint
   PaintPositions = posOfRelX( PaintX, PaintW );
 }
 
 
-void KBufferColumn::paintFirstLine( QPainter *P, KPixelX cx, KPixelX cw, int FirstLine )
+void KBufferColumn::paintFirstLine( QPainter *P, KPixelXs Xs, int FirstLine )
 {
-  // translate
-  cx -= x();
+  preparePainting( Xs );
 
-  // calculating the most right relative x to paint
-  KPixelX LastX = cx + cw - 1;
-  if( LastX >= width() )
-    LastX = width()-1;
-
-  // calculating the most left relative x to paint
-  PaintX = cx > 0 ? cx : 0;
-  // calculating the width
-  PaintW = LastX - PaintX + 1;
-
-  // get line positions to paint
-  PaintPositions = posOfRelX( PaintX, PaintW );
   PaintLine = FirstLine;
 
 //  kdDebug(1501) << "paintFirstLine:"<<cx<<","<<cw<<"|" <<PaintX<<","<<PaintW << ")\n";
@@ -406,7 +390,6 @@ void KBufferColumn::paintLine( QPainter *P, int Line ) // TODO: could be removed
 //     return;
 
   paintPositions( P, Line, PaintPositions );
-
 }
 
 
@@ -508,7 +491,8 @@ void KBufferColumn::paintPlain( QPainter *P, KSection Positions, int Index )
     // draw the byte
     P->translate( x, 0 );
     char Byte = Buffer->datum( Index );
-    drawByte( P, Byte, colorForByte(Byte) );
+    KHEChar B = Codec->decode( Byte );
+    drawByte( P, Byte, B, colorForChar(B) );
 
     P->translate( -x, 0 );
   }
@@ -522,7 +506,7 @@ void KBufferColumn::paintSelection( QPainter *P, KSection Positions, int Index,
   paintRange( P, CG.highlight(), Positions, Flag );
 
   const QColor &HTC = CG.highlightedText();
-  // paint all the bytes affected:repa
+  // paint all the bytes affected
   for( int p=Positions.start(); p<=Positions.end(); ++p,++Index )
   {
     KPixelX x = relXOfPos( p );
@@ -530,7 +514,8 @@ void KBufferColumn::paintSelection( QPainter *P, KSection Positions, int Index,
     // draw the byte
     P->translate( x, 0 );
     char Byte = Buffer->datum( Index );
-    drawByte( P, Byte, HTC );
+    KHEChar B = Codec->decode( Byte );
+    drawByte( P, Byte, B, HTC );
 
     P->translate( -x, 0 );
   }
@@ -552,7 +537,8 @@ void KBufferColumn::paintMarking( QPainter *P, KSection Positions, int Index, in
     // draw the byte
     P->translate( x, 0 );
     char Byte = Buffer->datum( Index );
-    drawByte( P, Byte, BC );
+    KHEChar B = Codec->decode( Byte );
+    drawByte( P, Byte, B, BC );
 
     P->translate( -x, 0 );
   }
@@ -593,6 +579,7 @@ void KBufferColumn::paintRange( QPainter *P, const QColor &Color, KSection Posit
 void KBufferColumn::paintByte( QPainter *P, int Index )
 {
   char Byte = ( Index > -1 ) ? Buffer->datum( Index ) : EmptyByte;
+  KHEChar B = Codec->decode( Byte );
 
   const QColorGroup &CG = View->colorGroup();
   QColor Color = CG.text();
@@ -613,14 +600,14 @@ void KBufferColumn::paintByte( QPainter *P, int Index )
     else
     {
       Brush.setColor( CG.base() );
-      Color = colorForByte( Byte );
+      Color = colorForChar( B );
     }
   }
 
   P->fillRect( 0,0,ByteWidth,LineHeight, Brush );
 
   if( Index > -1 )
-    drawByte( P, Byte, Color );
+    drawByte( P, Byte, B, Color );
 }
 
 
@@ -628,7 +615,9 @@ void KBufferColumn::paintFramedByte( QPainter *P, int Index, KFrameStyle FrameSt
 {
   paintByte( P, Index );
   char Byte = ( Index > -1 ) ? Buffer->datum( Index ) : EmptyByte;
-  P->setPen( colorForByte(Byte) );
+  KHEChar B = Codec->decode( Byte );
+
+  P->setPen( colorForChar(B) );
   if( FrameStyle == Frame )
     P->drawRect( 0, 0, ByteWidth, LineHeight );
   else if( FrameStyle == Left )
@@ -641,14 +630,15 @@ void KBufferColumn::paintFramedByte( QPainter *P, int Index, KFrameStyle FrameSt
 void KBufferColumn::paintCursor( QPainter *P, int Index )
 {
   char Byte = ( Index > -1 ) ? Buffer->datum( Index ) : EmptyByte;
-  P->fillRect( 0, 0, ByteWidth, LineHeight, QBrush(colorForByte(Byte),Qt::SolidPattern) );
+  KHEChar B = Codec->decode( Byte );
+  P->fillRect( 0, 0, ByteWidth, LineHeight, QBrush(colorForChar(B),Qt::SolidPattern) );
 }
 
 
-void KBufferColumn::drawByte( QPainter *P, char Byte, const QColor &Color ) const
+void KBufferColumn::drawByte( QPainter *P, char /*Byte*/, KHEChar B, const QColor &Color ) const
 {
   P->setPen( Color );
-  P->drawText( 0, DigitBaseLine, QString::fromAscii(&Byte,1) );
+  P->drawText( 0, DigitBaseLine, B );
 }
 
 
