@@ -18,7 +18,10 @@
 #ifndef KHE_KOFFSETCOLTEXTEXPORT_H
 #define KHE_KOFFSETCOLTEXTEXPORT_H
 
+// lib specific
 #include "kcoltextexport.h"
+#include "koffsetformat.h"
+
 
 namespace KHE
 {
@@ -31,16 +34,21 @@ class KOffsetColTextExport : public KColTextExport
     KOffsetColTextExport( const KOffsetColumn *OC );
 
   public: // KColTextExport API
-    void printFirstLine( char **T, int Line ) const;
-    void printNextLine( char **T ) const;
+    void printFirstLine( QString &T, int Line ) const;
+    void printNextLine( QString &T ) const;
     /** tells how much chars per line are needed */
     int charsPerLine() const;
 
   protected:
-    void print( char **T ) const;
+    void print( QString &T ) const;
 
   protected:
-    const KOffsetColumn *OffsetColumn;
+    const int CodingWidth;
+    const int FirstLineOffset;
+    const int Delta;
+    const KOffsetFormat::print printFunction;
+
+    /** the line we are in */
     mutable int PrintLine;
 };
 
