@@ -306,8 +306,12 @@ bool KJotsBook::openBook(const QString& filename)
     
             if ( file.exists() && file.open(IO_ReadWrite) ) //TODO: Implement read-only mode?
             {
+                QTextStream st(static_cast<QIODevice*>(&file));
+                st.setEncoding(  KJotsSettings::unicode() ? QTextStream::UnicodeUTF8 : QTextStream::Locale );
+                QString data = st.read();
+
                 QDomDocument doc( "KJots" );
-                if ( doc.setContent( &file ) ) 
+                if ( doc.setContent( data ) ) 
                 {
                     QDomElement docElem = doc.documentElement();
             
