@@ -19,7 +19,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 // my headers:
@@ -35,6 +35,7 @@
 #include <kicondialog.h>
 #include <kapplication.h>
 #include <kmessagebox.h>
+#include <krichtextlabel.h>
 
 // other Qt headers:
 #include <qlayout.h>
@@ -161,7 +162,8 @@ BatteryConfig::BatteryConfig (QWidget * parent, const char *name)
             (void)startTimer(30*1000);	// update 2x every minute
       }
 
-      QLabel* explain = new QLabel( i18n("This panel controls whether the battery status monitor\nappears in the system tray and what it looks like."), this);
+      // TODO: remove linefeed from string, can't do it right now coz we have a string freeze
+      QLabel* explain = new KRichTextLabel( i18n("This panel controls whether the battery status monitor\nappears in the system tray and what it looks like.").replace("\n"," "), this);
       top_layout->addWidget(explain, 0);
       laptop_portable::extra_config(this, config, top_layout);
     }
@@ -170,8 +172,6 @@ BatteryConfig::BatteryConfig (QWidget * parent, const char *name)
     startMonitor = new QPushButton( i18n("&Start Battery Monitor"), this);
     connect(startMonitor, SIGNAL(clicked()), this, SLOT(slotStartMonitor()));
     top_layout->addWidget( startMonitor, 0, Qt::AlignRight );
-    top_layout->addWidget( new QLabel( i18n("Version: %1").arg(LAPTOP_VERSION), this), 0, Qt::AlignRight );
-
 
     load();
 }
@@ -259,7 +259,7 @@ void BatteryConfig::defaults()
         }
         battery_pm = SmallIcon(nochargebattery, 20, KIcon::DefaultState, instance);
         battery_nopm = SmallIcon(nobattery, 20, KIcon::DefaultState, instance);
-        changed(false);
+        changed(true);
 	BatteryStateUpdate();
 }
 
