@@ -9,7 +9,7 @@
  *
  * This file contains the implementation of the main laptop battery monitoring daemon
  *
- * $Id: daemon_state.cpp 490596 2005-12-22 13:05:45Z scripty $
+ * $Id: daemon_state.cpp 533059 2006-04-23 14:55:56Z charles $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -187,7 +187,7 @@ void daemon_state::load()
         playSound[1] = config->readBoolEntry("PlaySound", false)&exists;
         playSoundPath[1] = config->readEntry("PlaySoundPath");
         systemBeep[1] = config->readBoolEntry("SystemBeep", true)&exists;
-        logout[1] = config->readBoolEntry("Logout", true)&exists;
+        logout[1] = config->readBoolEntry("Logout", false)&exists;
         shutdown[1] = config->readBoolEntry("Shutdown", true)&exists;
         notify[1] = config->readBoolEntry("Notify", (can_suspend?false:true))&exists;
         do_hibernate[1] = config->readBoolEntry("Hibernate", false)&can_hibernate&exists;
