@@ -19,7 +19,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "power.h"
@@ -148,7 +148,8 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
 		nopowerValBrightness = new QSlider(0, 255, 16, 255, Qt::Horizontal, wp);
         	QToolTip::add( nopowerValBrightness, i18n( "How bright to change the back panel" ) );
 		nopowerValBrightness->setEnabled(0);
-		connect (nopowerValBrightness, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+		connect(nopowerValBrightness, SIGNAL(valueChanged(int)), this, SLOT(changed()));
+		connect(nopowerBrightness, SIGNAL(toggled(bool)), nopowerValBrightness, SLOT(setEnabled(bool)));
 		xl->addWidget(nopowerValBrightness);
 		xl->addWidget(new QLabel("+", wp));
 		xl->addStretch(1);
@@ -163,7 +164,8 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
         	QToolTip::add( nopowerValPerformance, i18n( "Which profile to change it to" ) );
 		nopowerValPerformance->insertStringList(performance_list);
     		nopowerValPerformance->setEnabled(0);
-    		connect (nopowerValPerformance, SIGNAL(activated(int)), this, SLOT(configChanged()));
+		connect(nopowerValPerformance, SIGNAL(activated(int)), this, SLOT(changed()));
+		connect(nopowerPerformance, SIGNAL(toggled(bool)), nopowerValPerformance, SLOT(setEnabled(bool)));
 		xl->addWidget(nopowerValPerformance);
 		xl->addStretch(1);
       } 
@@ -177,23 +179,25 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
         	QToolTip::add( nopowerValThrottle, i18n( "How much to throttle the laptop's CPU" ) );
 		nopowerValThrottle->insertStringList(throttle_list);
     		nopowerValThrottle->setEnabled(0);
-    		connect (nopowerValThrottle, SIGNAL(activated(int)), this, SLOT(configChanged()));
+		connect(nopowerValThrottle, SIGNAL(activated(int)), this, SLOT(changed()));
+		connect(nopowerThrottle, SIGNAL(toggled(bool)), nopowerValThrottle, SLOT(setEnabled(bool)));
 		xl->addWidget(nopowerValThrottle);
 		xl->addStretch(1);
       } 
 
 
-      connect(nopowerBox, SIGNAL(clicked(int)), this, SLOT(configChanged()));
+      connect(nopowerBox, SIGNAL(clicked(int)), this, SLOT(changed()));
 
       bool can_lav = laptop_portable::has_lav();
       QHBox *hbox;
       if (can_lav) {
       	  hbox = new QHBox( nopowerBox );
           noenablelav = new QCheckBox(i18n("Don't act if LAV is >"), hbox);
-          connect( noenablelav, SIGNAL(clicked()), this, SLOT(configChanged()));
+          connect(noenablelav, SIGNAL(clicked()), this, SLOT(changed()));
           noeditlav = new KDoubleSpinBox(0.0, 10.0, 0.0, 0.1, 1, hbox);
           QToolTip::add( noeditlav, i18n( "If enabled and the system load average is greater than this value none of the above options will be applied" ) );
-          connect( noeditlav, SIGNAL(valueChanged(double)), this, SLOT(configChanged()));
+          connect(noeditlav, SIGNAL(valueChanged(double)), this, SLOT(changed()));
+          connect(noenablelav, SIGNAL(toggled(bool)), noeditlav, SLOT(setEnabled(bool)));
       }
 
       hbox = new QHBox( nopowerBox );
@@ -203,7 +207,7 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
       noeditwait->setSuffix( i18n("keep short, unit in spinbox", "min") );
       noedlabel->setBuddy( noeditwait );
       hbox->setStretchFactor( noeditwait, 1 );
-      connect( noeditwait, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+      connect( noeditwait, SIGNAL(valueChanged(int)), this, SLOT(changed()));
 
 
 	///////////////////////////////////////////////////////////////
@@ -237,7 +241,8 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
 		powerValBrightness = new QSlider(0, 255, 16, 255, Qt::Horizontal, wp);
         	QToolTip::add( powerValBrightness, i18n( "How bright to change the back panel" ) );
 		powerValBrightness->setEnabled(0);
-		connect (powerValBrightness, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+		connect(powerValBrightness, SIGNAL(valueChanged(int)), this, SLOT(changed()));
+		connect(powerBrightness, SIGNAL(toggled(bool)), powerValBrightness, SLOT(setEnabled(bool)));
 		xl->addWidget(powerValBrightness);
 		xl->addWidget(new QLabel("+", wp));
 		xl->addStretch(1);
@@ -252,7 +257,8 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
         	QToolTip::add( powerValPerformance, i18n( "Which profile to change it to" ) );
 		powerValPerformance->insertStringList(performance_list);
     		powerValPerformance->setEnabled(0);
-    		connect (powerValPerformance, SIGNAL(activated(int)), this, SLOT(configChanged()));
+		connect(powerValPerformance, SIGNAL(activated(int)), this, SLOT(changed()));
+		connect(powerPerformance, SIGNAL(toggled(bool)), powerValPerformance, SLOT(setEnabled(bool)));
 		xl->addWidget(powerValPerformance);
 		xl->addStretch(1);
       } 
@@ -266,20 +272,22 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
         	QToolTip::add( powerValThrottle, i18n( "How much to throttle the laptop's CPU" ) );
 		powerValThrottle->insertStringList(throttle_list);
     		powerValThrottle->setEnabled(0);
-    		connect (powerValThrottle, SIGNAL(activated(int)), this, SLOT(configChanged()));
+		connect(powerValThrottle, SIGNAL(activated(int)), this, SLOT(changed()));
+		connect(powerThrottle, SIGNAL(toggled(bool)), powerValThrottle, SLOT(setEnabled(bool)));
 		xl->addWidget(powerValThrottle);
 		xl->addStretch(1);
       } 
 
-      connect(powerBox, SIGNAL(clicked(int)), this, SLOT(configChanged()));
+      connect(powerBox, SIGNAL(clicked(int)), this, SLOT(changed()));
 
       if (can_lav) {
           hbox = new QHBox( powerBox );
           enablelav = new QCheckBox(i18n("Don't act if LAV is >"), hbox);
-          connect( enablelav, SIGNAL(clicked()), this, SLOT(configChanged()));
+          connect( enablelav, SIGNAL(clicked()), this, SLOT(changed()));
           editlav = new KDoubleSpinBox(0.0, 10.0, 0.0, 0.1, 1, hbox);
           QToolTip::add( editlav, i18n( "If enabled and the system load average is greater than this value none of the above options will be applied" ) );
-          connect( editlav, SIGNAL(valueChanged(double)), this, SLOT(configChanged()));
+          connect( editlav, SIGNAL(valueChanged(double)), this, SLOT(changed()));
+          connect( enablelav, SIGNAL(toggled(bool)), editlav, SLOT(setEnabled(bool)) );
       }
 
       hbox = new QHBox( powerBox );
@@ -289,18 +297,21 @@ PowerConfig::PowerConfig (QWidget * parent, const char *name)
       editwait->setSuffix( i18n("keep short, unit in spinbox", "min") );
       edlabel->setBuddy( editwait );
       hbox->setStretchFactor( editwait, 1 );
-      connect( editwait, SIGNAL(valueChanged(int)), this, SLOT(configChanged()));
+      connect( editwait, SIGNAL(valueChanged(int)), this, SLOT(changed()));
 
       hlay->addStretch(1);
 
-      QLabel* explain = new QLabel(i18n("This panel configures the behavior of the automatic power-down feature - it works as a sort of extreme\n"
-			                "screen saver. You can configure different timeouts and types of behavior depending on whether or not\n"
-					"your laptop is plugged in to the mains supply."), this);
-      top_layout->addWidget(explain, 0, Qt::AlignLeft);
+      QLabel* explain = new QLabel(i18n("This panel configures the behavior of the automatic power-down feature - "
+					"it works as a sort of extreme screen saver. You can configure different "
+					"timeouts and types of behavior depending on whether or not your laptop is "
+					"plugged in to the mains supply."), this );
+      explain->setAlignment( Qt::WordBreak );
+      top_layout->addWidget(explain);
 
       if (can_standby) {
-	QLabel* explain3 = new QLabel(i18n("Different laptops may respond to 'standby' in different ways - in many it's only a temporary\n"
-				           "state and may not be useful for you."), this);
+	QLabel* explain3 = new QLabel(i18n("Different laptops may respond to 'standby' in different ways - in many "
+					"it is only a temporary state and may not be useful for you."), this);
+	explain3->setAlignment( Qt::WordBreak );
 	top_layout->addWidget(explain3, 0, Qt::AlignLeft);
       }
 
@@ -549,6 +560,7 @@ void PowerConfig::defaults()
 		powerValThrottle->setEnabled(power_throttle_enabled);
 	}
   }
+  changed(true);
 }
 
 int  PowerConfig::getNoPower()
@@ -630,32 +642,6 @@ void PowerConfig::setPower(int p, int np)
 }
 
 
-
-void PowerConfig::configChanged()
-{
-  if (editlav && enablelav)
-  	editlav->setEnabled(enablelav->isChecked());
-  if (noeditlav && noenablelav)
-  	noeditlav->setEnabled(noenablelav->isChecked());
-  if (powerBrightness) 
-	powerValBrightness->setEnabled(powerBrightness->isChecked());
-  if (nopowerBrightness) 
-	nopowerValBrightness->setEnabled(nopowerBrightness->isChecked());
-
-  if (powerPerformance) 
-	powerValPerformance->setEnabled(powerPerformance->isChecked());
-  if (nopowerPerformance) 
-	nopowerValPerformance->setEnabled(nopowerPerformance->isChecked());
-
-  if (powerThrottle) 
-	powerValThrottle->setEnabled(powerThrottle->isChecked());
-  if (nopowerThrottle) 
-	nopowerValThrottle->setEnabled(nopowerThrottle->isChecked());
-
-  emit changed(true);
-}
-
-
 QString PowerConfig::quickHelp() const
 {
   return i18n("<h1>Laptop Power Control</h1>This module allows you to "
