@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -37,6 +37,11 @@
 #include <kurlrequester.h>
 #include <kcmodule.h>
 
+#ifdef Q_OS_FREEBSD
+#include <sys/types.h>
+#include <sys/sysctl.h>
+#endif
+
 #include "kcmthinkpad_general.h"
 
 #include <dcopclient.h>
@@ -73,6 +78,25 @@ KCMThinkpadModule::KCMThinkpadModule(QWidget* parent, const char* name, const QS
 	//try and open /dev/nvram
 	m_nvramReadable = false;
 	m_nvramWriteable = false;
+
+#ifdef Q_OS_FREEBSD
+	// Look if the sysctl tree of acpi_ibm is in place
+	u_int n = 0;
+	size_t len = sizeof(n);
+	if (m_nvramReadable = ( sysctlbyname("dev.acpi_ibm.0.volume", &n, &len, NULL, 0) != -1 ))
+		m_nvramWriteable = ( sysctlbyname("dev.acpi_ibm.0.volume", NULL, NULL, &n, len) != -1 );
+
+	if (!m_nvramReadable) {
+		setButtons(buttons() & ~Default);
+		m_KCMThinkpadGeneral->bgGeneral->setEnabled(false);
+		m_KCMThinkpadGeneral->tlOff->setText(i18n("In order to use the Thinkpad Buttons KMilo Plugin, "
+							  "you have to load the acpi_ibm(4) driver."));
+	} else if (!m_nvramWriteable) {
+		m_KCMThinkpadGeneral->tlOff->setText(i18n("Could not write to dev.acpi_ibm.0.volume. "
+							  "Using software volume, required for "
+							  "R30/R31 models, or using a custom volume "
+							  "change step is disabled."));
+#else
 	QFile nvramFile(m_nvramFile);
 	if ( nvramFile.open(IO_ReadOnly) )  {
 		m_nvramReadable = true;
@@ -93,6 +117,7 @@ KCMThinkpadModule::KCMThinkpadModule(QWidget* parent, const char* name, const QS
 							  "change step, set the nvram device to world "
 							  "writeable: <em>chmod 666 "
 							  "/dev/nvram</em>").arg(m_nvramFile));
+#endif
 	} else {
 		m_KCMThinkpadGeneral->tlOff->setText(i18n("Thinkpad Buttons KMilo Plugin Ready For Configuration"));
 	}
