@@ -18,7 +18,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -35,12 +35,9 @@ class KCMThinkpadModule : public KCModule {
  public:
 	KCMThinkpadModule(QWidget* parent, const char* name, const QStringList&);
 
-	QString quickHelp() const;
 	void save();
 	void load();
 	void defaults();
- protected slots:
-	void moduleChanged();
  private:
 	KCMThinkpadGeneral* m_KCMThinkpadGeneral;
 	QString m_nvramFile;
