@@ -12,8 +12,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 #include "dragaccepter.h"
 #include "concwidget.h"
@@ -130,6 +130,7 @@ void DragAccepter::dropEvent(QDropEvent *event)
   else {
     // selection should not be cleared here, since we might want to delete it.
   }
+  event->accept();
 }
 
 RegExp* DragAccepter::regExp() const
