@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "pluginmodule.h"
@@ -102,7 +102,10 @@ KSim::PluginPage::~PluginPage()
 
 KConfig *KSim::PluginPage::config() const
 {
-  return d->config;
+  if (d)
+    return d->config;
+  else
+    return 0;
 }
 
 class KSim::PluginView::Private
@@ -133,9 +136,10 @@ KSim::PluginView::PluginView(KSim::PluginObject *parent, const char *name)
 
 KSim::PluginView::~PluginView()
 {
-  delete d->config;
   delete d->popupMenu;
+  delete d->config;
   delete d;
+  d = 0;
 }
 
 KConfig *KSim::PluginView::config() const
