@@ -14,18 +14,19 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef KSIMCPU_H
 #define KSIMCPU_H
 
-#include <qptrlist.h>
-#include <qpair.h>
-
 #include <pluginmodule.h>
+#include <chart.h>
+#include <progress.h>
+
 #include <stdio.h>
 
+class QPushButton;
 class QTextStream;
 class QVBoxLayout;
 class QHBoxLayout;
@@ -33,12 +34,8 @@ class QCheckBox;
 class QLabel;
 class QGroupBox;
 class QTimer;
+class QListViewItem;
 class KListView;
-namespace KSim
-{
-  class Chart;
-  class Progress;
-}
 
 class CpuPlugin : public KSim::PluginObject
 {
@@ -88,25 +85,112 @@ class CpuView : public KSim::PluginView
           return *this;
         }
     };
-    typedef QValueList<QPair<QString, QString> > CpuList;
-    typedef QPair<KSim::Chart *, KSim::Progress *> CpuPair;
 
+    class Cpu
+    {
+      public:
+        Cpu()
+        {
+          m_num = 0;
+          m_chart = 0;
+          m_label = 0;
+        }
+
+        Cpu(const QString &name,
+           const QString &format,
+           int number)
+           : m_name(name),
+           m_format(format),
+           m_num(number)
+        {
+          m_chart = 0;
+          m_label = 0;
+        }
+
+        ~Cpu()
+        {
+        }
+
+        bool operator==(const Cpu &rhs) const
+        {
+          return m_name == rhs.m_name &&
+             m_format == rhs.m_format;
+        }
+
+        bool operator!=(const Cpu &rhs) const
+        {
+          return !operator==(rhs);
+        }
+
+        void cleanup()
+        {
+          delete m_chart;
+          delete m_label;
+        }
+
+        void setData(const CpuData &data)
+        {
+          m_old = m_data;
+          m_data = data;
+        }
+
+        const CpuData &oldData() const
+        {
+          return m_old;
+        }
+
+        const QString &format() const
+        {
+          return m_format;
+        }
+
+        int number() const
+        {
+          return m_num;
+        }
+
+        void setDisplay(KSim::Chart *chart, KSim::Progress *label)
+        {
+          m_chart = chart;
+          m_label = label;
+          m_label->setText(m_name);
+        }
+
+        KSim::Chart *chart()
+        {
+          return m_chart;
+        }
+
+        KSim::Progress *label()
+        {
+          return m_label;
+        }
+
+      private:
+        CpuData m_data;
+        CpuData m_old;
+        QString m_name;
+        QString m_format;
+        KSim::Chart *m_chart;
+        KSim::Progress *m_label;
+        int m_num;
+    };
+
+    typedef QValueList<Cpu> CpuList;
     void updateCpu(CpuData &cpu, int cpuNumber);
-    void init();
-    void cleanup();
+    CpuList createList();
 
-    CpuList createCpuList(KConfig *);
-    CpuPair *addCpu(KSim::Chart *chart, KSim::Progress *progress,
-       const QString &text);
+    void addDisplay();
+    void cleanup(CpuList &);
+
+    KSim::Chart *addChart();
+    KSim::Progress *addLabel();
 
-    QPtrList<CpuPair> m_chartList;
     QTimer *m_timer;
     QVBoxLayout *m_mainLayout;
-    CpuData *m_oldData;
-    CpuData *m_data;
-    int m_firstTime;
-
+    bool m_firstTime;
     CpuList m_cpus;
+
 #ifdef __linux__
     FILE *m_procFile;
     QTextStream *m_procStream;
@@ -123,6 +207,10 @@ class CpuConfig : public KSim::PluginPage
     virtual void saveConfig();
     virtual void readConfig();
 
+  private slots:
+    void modify( QListViewItem * );
+    void modify();
+
   private:
     uint addCpus();
 
@@ -134,5 +222,7 @@ class CpuConfig : public KSim::PluginPage
     QLabel *m_userLabel;
     QLabel *m_niceLabel;
     QVBoxLayout *m_legendLayout;
+
+    QPushButton * m_modify;
 };
 #endif
