@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "fsystemconfig.h"
@@ -53,7 +53,7 @@ FsystemConfig::FsystemConfig(KSim::PluginObject *parent, const char *name)
   m_mainLayout->setSpacing(6);
 
   m_availableMounts = new KListView(this);
-  m_availableMounts->addColumn(i18n("Mounted Partitions"));
+  m_availableMounts->addColumn(i18n("Mounted Partition"));
   m_availableMounts->addColumn(i18n("Device"));
   m_availableMounts->addColumn(i18n("Type"));
   m_mainLayout->addMultiCellWidget(m_availableMounts, 0, 0, 0, 3);
