@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include "sensorbase.h"
@@ -53,7 +53,6 @@ SensorBase *SensorBase::self()
 SensorBase::SensorBase() : QObject()
 {
   KSim::Config::config()->setGroup("Sensors");
-  m_fahrenheit = KSim::Config::config()->readBoolEntry("displayFahrenheit", false);
   QCString sensorsName("libsensors.so");
 
   QStringList sensorLocations = KSim::Config::config()->readListEntry("sensorLocations");
@@ -76,12 +75,8 @@ SensorBase::SensorBase() : QObject()
       m_hasNVControl = XNVCTRLQueryExtension(qt_xdisplay(), &eventBase, &errorBase) == True;
   }
 
-
-
-  int updateVal = KSim::Config::config()->readNumEntry("sensorUpdateValue", 15);
   m_updateTimer = new QTimer(this);
   connect(m_updateTimer, SIGNAL(timeout()), SLOT(update()));
-  setUpdateSpeed(updateVal * 1000);
 }
 
 SensorBase::~SensorBase()
@@ -217,17 +212,17 @@ bool SensorBase::init()
 
 QString SensorBase::sensorType(const QString &name)
 {
-  if (name.findRev("fan") != -1)
-    return QString::fromLatin1("RPM");
+  if (name.findRev("fan", -1, false) != -1)
+    return i18n("Rounds per minute", " RPM");
 
-  if (name.findRev("temp") != -1)
+  if (name.findRev("temp", -1, false) != -1)
     if (SensorBase::fahrenheit())
       return QString::fromLatin1("F");
     else
       return QString::fromLatin1("C");
 
   if (name.findRev(QRegExp("[^\\+]?[^\\-]?V$")) != -1)
-    return QString::fromLatin1("V");
+    return i18n("Volt", "V");
 
   return QString::null;
 }
@@ -244,7 +239,7 @@ QString SensorBase::chipsetString(const ChipName *c)
 
 float SensorBase::formatValue(const QString &label, float value)
 {
-  if (label.findRev("temp") != -1)
+  if (label.findRev("temp", -1, false) != -1)
       return toFahrenheit(value);
 
  return value;
@@ -252,8 +247,8 @@ float SensorBase::formatValue(const QString &label, float value)
 
 QString SensorBase::formatString(const QString &label, float value)
 {
-  if (label.findRev("fan") != -1)
+  if (label.findRev("fan", -1, false) != -1)
     return QString::number(value);
 
-  return QString().sprintf("%.2f", value);
+  return QString::number(value,'f',2);
 }
