@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2003,2004 George Staikos <staikos@kde.org>
+   Copyright (C) 2003-2005 George Staikos <staikos@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
  */
 
 #include <kaboutdata.h>
@@ -55,6 +55,7 @@ int main(int argc, char **argv) {
 		"http://www.kde.org/");
 
 	about.addAuthor("George Staikos", I18N_NOOP("Primary author and maintainer"), "staikos@kde.org");
+	about.addAuthor("Isaac Clerencia", I18N_NOOP("Developer"), "isaac@warp.es");
 
 	KCmdLineArgs::init(argc, argv, &about);
 	KCmdLineArgs::addCmdLineOptions(options);
